@@ -8,27 +8,26 @@ use Apache::Singleton;
 use base qw(Apache::Singleton);
 
 BEGIN { 
-	use constant MP2 => eval { require mod_perl; $mod_perl::VERSION > 1.99 };
-	die "mod_perl is required to run this module: $@" if $@;
+    use constant MP2 => $mod_perl::VERSION >= 1.99 ? 1 : 0;
 
-	if (MP2) { 
-		require Apache::RequestUtil; 
-	}
-	else { 
-		require Apache;
-	}
+    if (MP2) {
+        require Apache2::RequestUtil;
+    }
+    else {
+        require Apache;
+    }
 }
 
 sub _get_instance {
     my $class = shift;
-    my $r = Apache->request;
+    my $r = MP2 ? Apache2::RequestUtil->request : Apache->request;
     my $key = "apache_singleton_$class";
     return $r->pnotes($key);
 }
 
 sub _set_instance {
     my($class, $instance) = @_;
-    my $r = Apache->request;
+    my $r = MP2 ? Apache2::RequestUtil->request : Apache->request;
     my $key = "apache_singleton_$class";
     $r->pnotes($key => $instance);
 }
